@@ -24,8 +24,12 @@
 #include <vncdisplayenums.h>
 #include <vncdisplay.h>
 #include <vncgrabsequence.h>
-#if !GTK_CHECK_VERSION(3,0,0)
-#include <vncimageframebuffer.h>
-#endif
 
 #endif
+/*
+ * Local variables:
+ *  c-indent-level: 4
+ *  c-basic-offset: 4
+ *  indent-tabs-mode: nil
+ * End:
+ */
